==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicArrowButton.h <==
// public class javax.swing.plaf.basic.BasicArrowButton

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class 69f2be1043a99512 javax_swing_JButton
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 8116f47f48e97c09 javax_swing_plaf_basic_BasicArrowButton

// header file dependencies
// @dep_header javax_swing_JButton

#include "javax/swing/JButton.h"

#ifndef _JC_javax_swing_plaf_basic_BasicArrowButton_H_
#define _JC_javax_swing_plaf_basic_BasicArrowButton_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Polygon$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;
struct _jc_javax_swing_plaf_basic_BasicArrowButton$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs	_jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$refs	_jc_javax_swing_plaf_basic_BasicArrowButton$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$nonrefs	_jc_javax_swing_plaf_basic_BasicArrowButton$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$object	_jc_javax_swing_plaf_basic_BasicArrowButton$object;

typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$fields_struct	_jc_javax_swing_plaf_basic_BasicArrowButton$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicArrowButton$vmethods	_jc_javax_swing_plaf_basic_BasicArrowButton$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicArrowButton$vtable	_jc_javax_swing_plaf_basic_BasicArrowButton$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicArrowButton$vtype	_jc_javax_swing_plaf_basic_BasicArrowButton$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicArrowButton$fields_struct {
	struct _jc_java_awt_Polygon$object	*downIcon;
	struct _jc_java_awt_Polygon$object	*leftIcon;
	struct _jc_java_awt_Polygon$object	*rightIcon;
	struct _jc_java_awt_Polygon$object	*upIcon;
	jint	defaultSize;
};
extern _jc_javax_swing_plaf_basic_BasicArrowButton$fields_struct _jc_javax_swing_plaf_basic_BasicArrowButton$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, jint);
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$_init$5dd8ed0013db12ce(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicArrowButton$method$getDirection$32bb50e14cdc527a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicArrowButton$method$getMaximumSize$d24ee7fdb96c1fa3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicArrowButton$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicArrowButton$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicArrowButton$method$isFocusTraversable$7a5a57868f3b610f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$paintTriangle$dc967d4f8ee735ec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, jboolean);
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$setDirection$85545d6389fea7b0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, jint);
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$getDirection$32bb50e14cdc527a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$getMaximumSize$d24ee7fdb96c1fa3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$getMinimumSize$f439289f02165af0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$isFocusTraversable$7a5a57868f3b610f;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$paintTriangle$dc967d4f8ee735ec;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$setDirection$85545d6389fea7b0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_awt_Color$object *_jc_javax_swing_plaf_basic_BasicArrowButton$method$access__240$80968610dd4f653c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
extern struct _jc_java_awt_Color$object *_jc_javax_swing_plaf_basic_BasicArrowButton$method$access__241$7a2a99883ed8a3e1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
extern struct _jc_java_awt_Color$object *_jc_javax_swing_plaf_basic_BasicArrowButton$method$access__242$74eb9df89c054788(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicArrowButton$vmethods {
	jint	(*getDirection$32bb50e14cdc527a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$d24ee7fdb96c1fa3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
	jboolean	(*isFocusTraversable$7a5a57868f3b610f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, struct _jc_java_awt_Graphics$object *);
	void	(*paintTriangle$dc967d4f8ee735ec)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, jboolean);
	void	(*setDirection$85545d6389fea7b0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicArrowButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JButton$vmethods	javax_swing_JButton;
	_jc_javax_swing_plaf_basic_BasicArrowButton$vmethods	javax_swing_plaf_basic_BasicArrowButton;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicArrowButton$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicArrowButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs {
	struct _jc_java_awt_Color$object	*shadow;
	struct _jc_java_awt_Color$object	*darkShadow;
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_object	*buttonBorder;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicArrowButton$refs {
    _jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs	javax_swing_plaf_basic_BasicArrowButton;
    _jc_javax_swing_JButton$sub_refs	javax_swing_JButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs {
	jint	direction;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicArrowButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JButton$sub_nonrefs	javax_swing_JButton;
    _jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs	javax_swing_plaf_basic_BasicArrowButton;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicArrowButton$object {
	_jc_javax_swing_plaf_basic_BasicArrowButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicArrowButton$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicArrowButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicArrowButton$vtype _jc_javax_swing_plaf_basic_BasicArrowButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicArrowButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicArrowButton$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicArrowButton_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicArrowButton.h <==
// public class javax.swing.plaf.basic.BasicArrowButton

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7391d27632d03ad8 javax_swing_AbstractButton
// @dep_class 69f2be1043a99512 javax_swing_JButton
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class c353ac796f75eed1 javax_swing_plaf_basic_BasicArrowButton

// header file dependencies
// @dep_header javax_swing_JButton

#include "javax/swing/JButton.h"

#ifndef _JC_javax_swing_plaf_basic_BasicArrowButton_H_
#define _JC_javax_swing_plaf_basic_BasicArrowButton_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Polygon$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs	_jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$refs	_jc_javax_swing_plaf_basic_BasicArrowButton$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$nonrefs	_jc_javax_swing_plaf_basic_BasicArrowButton$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$object	_jc_javax_swing_plaf_basic_BasicArrowButton$object;

typedef struct _jc_javax_swing_plaf_basic_BasicArrowButton$fields_struct	_jc_javax_swing_plaf_basic_BasicArrowButton$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicArrowButton$vmethods	_jc_javax_swing_plaf_basic_BasicArrowButton$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicArrowButton$vtable	_jc_javax_swing_plaf_basic_BasicArrowButton$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicArrowButton$vtype	_jc_javax_swing_plaf_basic_BasicArrowButton$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicArrowButton$fields_struct {
	struct _jc_java_awt_Polygon$object	*downIcon;
	struct _jc_java_awt_Polygon$object	*leftIcon;
	struct _jc_java_awt_Polygon$object	*rightIcon;
	struct _jc_java_awt_Polygon$object	*upIcon;
	jint	defaultSize;
};
extern _jc_javax_swing_plaf_basic_BasicArrowButton$fields_struct _jc_javax_swing_plaf_basic_BasicArrowButton$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$_init$5dd8ed0013db12ce(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, jint, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicArrowButton$method$getDirection$32bb50e14cdc527a(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicArrowButton$method$getMaximumSize$d24ee7fdb96c1fa3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicArrowButton$method$getMinimumSize$f439289f02165af0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicArrowButton$method$getPreferredSize$4730bc91c97b24d9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicArrowButton$method$isFocusTraversable$7a5a57868f3b610f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$paintTriangle$dc967d4f8ee735ec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, jboolean) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$setDirection$85545d6389fea7b0(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$getDirection$32bb50e14cdc527a;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$getMaximumSize$d24ee7fdb96c1fa3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$getMinimumSize$f439289f02165af0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$getPreferredSize$4730bc91c97b24d9;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$isFocusTraversable$7a5a57868f3b610f;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$paintTriangle$dc967d4f8ee735ec;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$setDirection$85545d6389fea7b0;
extern _jc_method _jc_javax_swing_plaf_basic_BasicArrowButton$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_javax_swing_plaf_basic_BasicArrowButton$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicArrowButton$vmethods {
	jint	(*getDirection$32bb50e14cdc527a)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getMaximumSize$d24ee7fdb96c1fa3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getMinimumSize$f439289f02165af0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$4730bc91c97b24d9)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
	jboolean	(*isFocusTraversable$7a5a57868f3b610f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*paintTriangle$dc967d4f8ee735ec)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint, jboolean) _JC_JCNI_ATTR;
	void	(*setDirection$85545d6389fea7b0)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicArrowButton$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicArrowButton$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_AbstractButton$vmethods	javax_swing_AbstractButton;
	_jc_javax_swing_JButton$vmethods	javax_swing_JButton;
	_jc_javax_swing_plaf_basic_BasicArrowButton$vmethods	javax_swing_plaf_basic_BasicArrowButton;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicArrowButton$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicArrowButton$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs {
	struct _jc_java_awt_Color$object	*shadow;
	struct _jc_java_awt_Color$object	*darkShadow;
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_object	*buttonBorder;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicArrowButton$refs {
    _jc_javax_swing_plaf_basic_BasicArrowButton$sub_refs	javax_swing_plaf_basic_BasicArrowButton;
    _jc_javax_swing_JButton$sub_refs	javax_swing_JButton;
    _jc_javax_swing_AbstractButton$sub_refs	javax_swing_AbstractButton;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs {
	jint	direction;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicArrowButton$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_AbstractButton$sub_nonrefs	javax_swing_AbstractButton;
    _jc_javax_swing_JButton$sub_nonrefs	javax_swing_JButton;
    _jc_javax_swing_plaf_basic_BasicArrowButton$sub_nonrefs	javax_swing_plaf_basic_BasicArrowButton;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicArrowButton$object {
	_jc_javax_swing_plaf_basic_BasicArrowButton$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicArrowButton$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicArrowButton$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicArrowButton$vtype _jc_javax_swing_plaf_basic_BasicArrowButton$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicArrowButton, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicArrowButton$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicArrowButton_H_ */
